@@ -16,9 +16,9 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: build-defs.h.in 256027 2008-03-25 02:00:32Z sixd $ */
+/* $Id: build-defs.h.in 292156 2009-12-15 11:17:47Z jani $ */
 
-#define CONFIGURE_COMMAND " './configure'  '--prefix=/opt/php-5.3.1' '--with-config-file-path=/opt/php-5.3.1/etc' '--with-apxs2=/opt/httpd/bin/apxs' '--with-pear' '--enable-zend-multibyte' '--enable-mbstring' '--enable-mbregex' '--enable-exif' '--enable-soap' '--enable-sockets' '--enable-dbx' '--with-zlib' '--enable-sysvmsg' '--enable-sysvsem' '--enable-sysvshm' '--enable-shmop' '--with-readline' '--enable-ftp' '--with-openssl' '--with-pgsql' '--with-pdo-pgsql=/opt/pgsql' '--enable-sqlite-utf8'"
+#define CONFIGURE_COMMAND " './configure'  '--prefix=/opt/php-5.3.6' '--with-config-file-path=/opt/php-5.3.6/etc' '--with-config-file-scan-dir=/opt/php-5.3.6/etc/php.d' '--with-apxs2=/opt/httpd/bin/apxs' '--with-pear' '--enable-zend-multibyte' '--enable-mbstring' '--enable-mbregex' '--enable-exif' '--enable-soap' '--enable-sockets' '--with-zlib' '--enable-sysvmsg' '--enable-sysvsem' '--enable-sysvshm' '--enable-shmop' '--with-readline' '--enable-ftp' '--with-openssl' '--with-pgsql' '--with-pdo-pgsql=/opt/pgsql' '--enable-sqlite-utf8'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -75,15 +75,16 @@
 #define PHP_LDAP_LIBS		""
 #define PHP_BIRDSTEP_INCLUDE     ""
 #define PHP_BIRDSTEP_LIBS        ""
-#define PEAR_INSTALLDIR         "/opt/php-5.3.1/lib/php"
-#define PHP_INCLUDE_PATH	".:/opt/php-5.3.1/lib/php"
-#define PHP_EXTENSION_DIR       "/opt/php-5.3.1/lib/php/extensions/no-debug-non-zts-20090626"
-#define PHP_PREFIX              "/opt/php-5.3.1"
-#define PHP_BINDIR              "/opt/php-5.3.1/bin"
-#define PHP_LIBDIR              "/opt/php-5.3.1/lib/php"
-#define PHP_DATADIR             "/opt/php-5.3.1/share/php"
-#define PHP_SYSCONFDIR          "/opt/php-5.3.1/etc"
-#define PHP_LOCALSTATEDIR       "/opt/php-5.3.1/var"
-#define PHP_CONFIG_FILE_PATH    "/opt/php-5.3.1/etc"
-#define PHP_CONFIG_FILE_SCAN_DIR    ""
+#define PEAR_INSTALLDIR         "/opt/php-5.3.6/lib/php"
+#define PHP_INCLUDE_PATH	".:/opt/php-5.3.6/lib/php"
+#define PHP_EXTENSION_DIR       "/opt/php-5.3.6/lib/php/extensions/no-debug-non-zts-20090626"
+#define PHP_PREFIX              "/opt/php-5.3.6"
+#define PHP_BINDIR              "/opt/php-5.3.6/bin"
+#define PHP_SBINDIR             "/opt/php-5.3.6/sbin"
+#define PHP_LIBDIR              "/opt/php-5.3.6/lib/php"
+#define PHP_DATADIR             "/opt/php-5.3.6/share/php"
+#define PHP_SYSCONFDIR          "/opt/php-5.3.6/etc"
+#define PHP_LOCALSTATEDIR       "/opt/php-5.3.6/var"
+#define PHP_CONFIG_FILE_PATH    "/opt/php-5.3.6/etc"
+#define PHP_CONFIG_FILE_SCAN_DIR    "/opt/php-5.3.6/etc/php.d"
 #define PHP_SHLIB_SUFFIX        "so"
